@@ -2274,7 +2274,7 @@ class VariableOsInstallMbr(LocationHelper, Variable):
                     # проверка размера EF02 при установке на btrfs
                     elif useBtrfs:
                         if (bbsize.isdigit() and bios_grub_size.isdigit() and
-                                    round(float(bbsize)) < round(float(bios_grub_size))):
+                                    round(float(bbsize) / Sizes.M) < round(float(bios_grub_size)/ Sizes.M)):
                             raise VariableError(
                                 _("Your boot device must have a BIOS Boot "
                                   "partition ({minsize})").format(
