@@ -341,7 +341,7 @@ class KernelHelper(VariableInterface):
         filesWithType = map(lambda x: (x, ftype(x)),
                             filter(path.exists,
                                    filelist))
-        return filter(lambda x: descr in x[1], filesWithType)
+        return filter(lambda x: x[1] and descr in x[1], filesWithType)
 
     def getInitrdFiles(self, pathname):
         filelist = map(lambda x: path.join(pathname, x), os.listdir(pathname))
